/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.tkhcalculation;

import java.io.Serializable;

/**
 * Result of a transport bodies height calculation.
 *
 * @author Gernot Belger
 */
public final class Tkh implements Serializable {

    private static final long serialVersionUID = 1L;

    private final double km;

    private final double wst;

    private final double meanBedHeight;

    private final double flowDepth;

    private final double flowDepthTkh;

    private final double discharge;

    private final SoilKind kind;

    private final double tkh;

    private final double tkhUp;

    private final double tkhDown;

    private final double velocity;

    private final double d50;

    private final double tau;

    public Tkh(final double km, final double wst, final double meanBedHeight, final double flowDepth, final double discharge) {
        this(km, wst, meanBedHeight, flowDepth, discharge, null);
    }

    public Tkh(final double km, final double wst, final double meanBedHeight, final double flowDepth, final double discharge, final SoilKind kind) {
        this(km, wst, meanBedHeight, flowDepth, Double.NaN, discharge, kind, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN);
    }

    public Tkh(final double km, final double wst, final double meanBedHeight, final double flowDepth, final double flowDepthTkh, final double discharge,
            final SoilKind kind, final double tkh, final double tkhUp, final double tkhDown, final double velocity, final double d50, final double tau) {
        this.km = km;
        this.wst = wst;
        this.meanBedHeight = meanBedHeight;
        this.flowDepth = flowDepth;
        this.flowDepthTkh = flowDepthTkh;
        this.discharge = discharge;
        this.kind = kind;
        this.tkh = tkh;
        this.tkhUp = tkhUp;
        this.tkhDown = tkhDown;
        this.velocity = velocity;
        this.d50 = d50;
        this.tau = tau;
    }

    public double getStation() {
        return this.km;
    }

    public double getTkh() {
        return this.tkh;
    }

    public SoilKind getKind() {
        return this.kind;
    }

    public double getUp() {
        return this.tkhUp;
    }

    public double getDown() {
        return this.tkhDown;
    }

    public double getWaterlevel() {
        return this.wst;
    }

    public double getDischarge() {
        return this.discharge;
    }

    public double getMeanBedHeight() {
        return this.meanBedHeight;
    }

    public double getFlowDepth() {
        return this.flowDepth;
    }

    public double getFlowDepthTkh() {
        return this.flowDepthTkh;
    }

    public double getVelocity() {
        return this.velocity;
    }

    public double getD50() {
        return this.d50;
    }

    public double getTau() {
        return this.tau;
    }
}